@@ -1,7 +1,6 @@
 """Small plotting-related utility functions."""
 from __future__ import print_function, division
 import colorsys
-import warnings
 import os
 
 import numpy as np
@@ -15,6 +14,28 @@ from distutils.version import LooseVersion
 pandas_has_categoricals = LooseVersion(pd.__version__) >= "0.15"
 mpl_ge_150 = LooseVersion(mpl.__version__) >= "1.5.0"
 from .external.six.moves.urllib.request import urlopen, urlretrieve
+from .external.six.moves.http_client import HTTPException
+
+
+__all__ = ["desaturate", "saturate", "set_hls_values",
+           "despine", "get_dataset_names", "load_dataset"]
+
+
+def remove_na(arr):
+    """Helper method for removing NA values from array-like.
+
+    Parameters
+    ----------
+    arr : array-like
+        The array-like from which to remove NA values.
+
+    Returns
+    -------
+    clean_arr : array-like
+        The original array with NA values removed.
+
+    """
+    return arr[pd.notnull(arr)]
 
 
 def ci_to_errsize(cis, heights):
@@ -169,11 +190,13 @@ def despine(fig=None, ax=None, top=True, right=True, left=False,
         Specific axes object to despine.
     top, right, left, bottom : boolean, optional
         If True, remove that spine.
-    offset : int or None  (default), optional
+    offset : int or dict, optional
         Absolute distance, in points, spines should be moved away
-        from the axes (negative values move spines inward).
+        from the axes (negative values move spines inward). A single value
+        applies to all spines; a dict can be used to set offset values per
+        side.
     trim : bool, optional
-        If true, limit spines to the smallest and largest major tick
+        If True, limit spines to the smallest and largest major tick
         on each non-despined axis.
 
     Returns
@@ -195,7 +218,11 @@ def despine(fig=None, ax=None, top=True, right=True, left=False,
             is_visible = not locals()[side]
             ax_i.spines[side].set_visible(is_visible)
             if offset is not None and is_visible:
-                _set_spine_position(ax_i.spines[side], ('outward', offset))
+                try:
+                    val = offset.get(side, 0)
+                except AttributeError:
+                    val = offset
+                _set_spine_position(ax_i.spines[side], ('outward', val))
 
         # Set the ticks appropriately
         if bottom:
@@ -234,44 +261,6 @@ def despine(fig=None, ax=None, top=True, right=True, left=False,
                 ax_i.set_yticks(newticks)
 
 
-def offset_spines(offset=10, fig=None, ax=None):
-    """Simple function to offset spines away from axes.
-
-    Use this immediately after creating figure and axes objects.
-    Offsetting spines after plotting or manipulating the axes
-    objects may result in loss of labels, ticks, and formatting.
-
-    Parameters
-    ----------
-    offset : int, optional
-        Absolute distance, in points, spines should be moved away
-        from the axes (negative values move spines inward).
-    fig : matplotlib figure, optional
-        Figure to despine all axes of, default uses current figure.
-    ax : matplotlib axes, optional
-        Specific axes object to despine
-
-    Returns
-    -------
-    None
-
-    """
-    warn_msg = "`offset_spines` is deprecated and will be removed in v0.5"
-    warnings.warn(warn_msg, UserWarning)
-
-    # Get references to the axes we want
-    if fig is None and ax is None:
-        axes = plt.gcf().axes
-    elif fig is not None:
-        axes = fig.axes
-    elif ax is not None:
-        axes = [ax]
-
-    for ax_i in axes:
-        for spine in ax_i.spines.values():
-            _set_spine_position(spine, ('outward', offset))
-
-
 def _set_spine_position(spine, position):
     """
     Set the spine's position without resetting an associated axis.
@@ -369,7 +358,7 @@ def get_dataset_names():
     gh_list = BeautifulSoup(http)
 
     return [l.text.replace('.csv', '')
-            for l in gh_list.find_all("a", {"class": "js-directory-link"})
+            for l in gh_list.find_all("a", {"class": "js-navigation-open"})
             if l.text.endswith('.csv')]
 
 
@@ -405,12 +394,13 @@ def load_dataset(name, cache=True, data_home=None, **kws):
     cache : boolean, optional
         If True, then cache data locally and use the cache on subsequent calls
     data_home : string, optional
-        The directory in which to cache data. By default, uses ~/seaborn_data/
+        The directory in which to cache data. By default, uses ~/seaborn-data/
     kws : dict, optional
         Passed to pandas.read_csv
 
     """
-    path = "https://github.com/mwaskom/seaborn-data/raw/master/{0}.csv"
+    path = ("https://raw.githubusercontent.com/"
+            "mwaskom/seaborn-data/master/{}.csv")
     full_path = path.format(name)
 
     if cache:
@@ -541,3 +531,101 @@ def get_color_cycle():
         except KeyError:
             pass  # just return axes.color style below
     return mpl.rcParams['axes.color_cycle']
+
+
+def relative_luminance(color):
+    """Calculate the relative luminance of a color according to W3C standards
+
+    Parameters
+    ----------
+    color : matplotlib color or sequence of matplotlib colors
+        Hex code, rgb-tuple, or html color name.
+
+    Returns
+    -------
+    luminance : float(s) between 0 and 1
+
+    """
+    rgb = mpl.colors.colorConverter.to_rgba_array(color)[:, :3]
+    rgb = np.where(rgb <= .03928, rgb / 12.92, ((rgb + .055) / 1.055) ** 2.4)
+    lum = rgb.dot([.2126, .7152, .0722])
+    try:
+        return lum.item()
+    except ValueError:
+        return lum
+
+
+def to_utf8(obj):
+    """Return a Unicode string representing a Python object.
+
+    Unicode strings (i.e. type ``unicode`` in Python 2.7 and type ``str`` in
+    Python 3.x) are returned unchanged.
+
+    Byte strings (i.e. type ``str`` in Python 2.7 and type ``bytes`` in
+    Python 3.x) are returned as UTF-8-encoded strings.
+
+    For other objects, the method ``__str__()`` is called, and the result is
+    returned as a UTF-8-encoded string.
+
+    Parameters
+    ----------
+    obj : object
+        Any Python object
+
+    Returns
+    -------
+    s : unicode (Python 2.7) / str (Python 3.x)
+        UTF-8-encoded string representation of ``obj``
+    """
+    if isinstance(obj, str):
+        try:
+            # If obj is a string, try to return it as a Unicode-encoded
+            # string:
+            return obj.decode("utf-8")
+        except AttributeError:
+            # Python 3.x strings are already Unicode, and do not have a
+            # decode() method, so the unchanged string is returned
+            return obj
+
+    try:
+        if isinstance(obj, unicode):
+            # do not attemt a conversion if string is already a Unicode
+            # string:
+            return obj
+        else:
+            # call __str__() for non-string object, and return the
+            # result to Unicode:
+            return obj.__str__().decode("utf-8")
+    except NameError:
+        # NameError is raised in Python 3.x as type 'unicode' is not
+        # defined.
+        if isinstance(obj, bytes):
+            return obj.decode("utf-8")
+        else:
+            return obj.__str__()
+
+
+def _network(t=None, url='http://google.com'):
+    """
+    Decorator that will skip a test if `url` is unreachable.
+
+    Parameters
+    ----------
+    t : function, optional
+    url : str, optional
+    """
+    import nose
+
+    if t is None:
+        return lambda x: _network(x, url=url)
+
+    def wrapper(*args, **kwargs):
+        # attempt to connect
+        try:
+            f = urlopen(url)
+        except (IOError, HTTPException):
+            raise nose.SkipTest()
+        else:
+            f.close()
+            return t(*args, **kwargs)
+    return wrapper
